@@ -26,6 +26,18 @@
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_POINTER_SIZE 4
 
+#if defined(QT_BUILTIN_GIF_READER) && defined(QT_NO_BUILTIN_GIF_READER)
+# undef QT_BUILTIN_GIF_READER
+#elif !defined(QT_BUILTIN_GIF_READER) && !defined(QT_NO_BUILTIN_GIF_READER)
+# define QT_BUILTIN_GIF_READER 1
+#endif
+
+#if defined(QT_NO_GSTREAMER) && defined(QT_GSTREAMER)
+# undef QT_NO_GSTREAMER
+#elif !defined(QT_NO_GSTREAMER) && !defined(QT_GSTREAMER)
+# define QT_NO_GSTREAMER
+#endif
+
 #if defined(QT_NO_IMAGEFORMAT_JPEG) && defined(QT_IMAGEFORMAT_JPEG)
 # undef QT_NO_IMAGEFORMAT_JPEG
 #elif !defined(QT_NO_IMAGEFORMAT_JPEG) && !defined(QT_IMAGEFORMAT_JPEG)
@@ -50,6 +62,12 @@
 # define QT_NO_NAS
 #endif
 
+#if defined(QT_NO_PHONON) && defined(QT_PHONON)
+# undef QT_NO_PHONON
+#elif !defined(QT_NO_PHONON) && !defined(QT_PHONON)
+# define QT_NO_PHONON
+#endif
+
 #if defined(QT_NO_SXE) && defined(QT_SXE)
 # undef QT_NO_SXE
 #elif !defined(QT_NO_SXE) && !defined(QT_SXE)
